# Mr Clean

This is a small package for cleaning data. Feel free to use it to clean other, non data-related things though.

## How to download
The source code is currently hosted on GitHub at:
https://github.com/A1Liu/mr_clean

You can also download the latest release from the [Python
package index](https://pypi.org/project/mr-clean/).

```sh
# could be pip3 instead of pip
pip install mr_clean
```

## Dependencies
- [NumPy](https://www.numpy.org): 1.9.0 or higher
- [pandas](https://pandas.pydata.org/): 0.23.3 or higher
